Module: Textus::Application::Caps

Defined in:
lib/textus/application/caps.rb

Overview

Capability records: role-scoped slices of the Store handed to use cases. Zeitwerk maps this file to Textus::Application::Caps; the three concrete cap types are also promoted to the Application namespace for concise reference (Application::ReadCaps, etc.).

Defined Under Namespace

Classes: HookCaps, ReadCaps, WriteCaps