Module: Textus::Application::Read::Blame

Defined in:
lib/textus/application/read/blame.rb

Overview

For one key, joins every audit-log row with the git commit (sha, author, date, subject) that introduced the file state at that audit row. Falls back to ‘git => nil` when not in a git repo or when the file is untracked.

Defined Under Namespace

Classes: Impl

Class Method Summary collapse

Class Method Details

.call(session:, ctx:, caps:) ⇒ Object

rubocop:disable Lint/UnusedMethodArgument



11
12
13
# File 'lib/textus/application/read/blame.rb', line 11

def self.call(*, session:, ctx:, caps:, **) # rubocop:disable Lint/UnusedMethodArgument
  Impl.new(caps: caps).call(*, **)
end